@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package Email::MIME;
 # ABSTRACT: easy MIME message handling
-$Email::MIME::VERSION = '1.934';
+$Email::MIME::VERSION = '1.936';
 use Email::Simple 2.206; # header_raw
 use parent qw(Email::Simple);
 
@@ -378,7 +378,7 @@ sub parts_multipart {
   my @parts;
   for my $bit (@bits) {
     $bit =~ s/\A[\n\r]+//smg;
-    $bit =~ s/(?<!\x0d)$self->{mycrlf}\Z//smg;
+    $bit =~ s/(?<!\x0d)$self->{mycrlf}\Z//sm;
     my $email = (ref $self)->new($bit);
     push @parts, $email;
   }
@@ -857,7 +857,7 @@ Email::MIME - easy MIME message handling
 
 =head1 VERSION
 
-version 1.934
+version 1.936
 
 =head1 SYNOPSIS
 
